# 📺 yt-mpv

Watch a YouTube video without ads, while archiving to archive.org.

```bash
uvx yt-mpv install
```

Follow instructions to configure internet archive credentials, then drag
[the links](https://bitplane.net/dev/python/yt-mpv/install) to your bookmarks
bar. You can watch without archiving (takes a couple of seconds to open), or
click the watch+archive link to upload after watching. After closing MPV, it'll
download it again in highest quality in the background, and upload it to
archive.org with `$(whoami)-urlhash` as the item name.

You will, of course, need to install `mpv` in order to use it, and have an
archive.org account to configure the `internetarchive` uploader. You'll get XDG
desktop notifications 

## why?

This is what you get when you put 4 minutes of adverts after every 6 minutes
of content; someone spends a couple of hours fixing the problem.

## links

* [🏠 home](https://bitplane.net/dev/python/yt-mpv)
 * [🖇 bookmarklets](https://bitplane.net/dev/python/yt-mpv/install)
* [🐍 pypi](https://pypi.org/project/yt-mpv)
* [🐱 github](https://github.com/bitplane/yt-mpv)

